//#######################################################################
//#
//#	Copyright 	Earth People Technology Inc. 2016
//#
//#
//# File Name:  dso_define.v
//# Author:     Earth People Technology
//# Date:       March 22, 2016
//# Revision:   A
//#
//# Development: EPT Digital Storage Oscilloscope Project 
//# Application: Altera Cyclone IV FPGA
//# Description: This file contains verilog code which will allow access
//#              to Active Transfer Library. 
//#               
//#              
//#
//#************************************************************************
//#
//# Revision History:	
//#			DATE		VERSION		DETAILS		
//#			3/8/16	1			Created
//#
//#									
//#
//#######################################################################
`ifndef _TOP_DSO_DEFINE
 `define _TOP_DSO_DEFINE

 
    //////////////////////////////////////////////////////
    //  DSO MEMORY MAP
    //////////////////////////////////////////////////////
	//ADDRESS                   FUNCTION              RANGE
	//0x00                      adc_convst_delay_value[7 to 0]
	//0x01                      adc_convst_delay_value[15 to 8]
	//0x02                      adc_convst_delay_value[23 to 16]
	//0x03                      I2C_0_CH1_BS_MEMORY_LOCATION
	//0x04                      I2C_0_CH2_BS_MEMORY_LOCATION
	//0x05                      I2C_0_CH3_BS_MEMORY_LOCATION
	//0x06                      I2C_0_CH4_BS_MEMORY_LOCATION
	//0x07                      I2C_1_CH1_RG_MEMORY_LOCATION
	//0x08                      I2C_1_CH2_RG_MEMORY_LOCATION
	//0x09                      I2C_1_CH3_RG_MEMORY_LOCATION
	//0x0a                      I2C_1_CH4_RG_MEMORY_LOCATION
	//0x0b                      Reserved
	// To                       Reserved
	//0x0f                      Reserved
    //0x10                      PGA_CH1_MEMORY
    //0x12                      PGA_CH2_MEMORY
    //0x14                      PGA_CH3_MEMORY
    //0x16                      PGA_CH4_MEMORY
	//0x17                      Reserved
	// To                       Reserved
	//0x19                      Reserved
    //0x1a                      PGA_READ_MEMORY_LOCATION
    //0x1b                      PGA_CH1_MEMORY
	// To                       Reserved
	//0xff                      Reserved
	
	
    //////////////////////////////////////////////////////
    //  DSO MEMORY LOCATIONS
    //////////////////////////////////////////////////////
    //Memory Location for ADC CONVST Delay Value Bytes 1, 2, and 3
    `define ADC_CONVST_DLY_1_MEMORY_LOCATION      8'h00
    `define ADC_CONVST_DLY_2_MEMORY_LOCATION      8'h01
    `define ADC_CONVST_DLY_3_MEMORY_LOCATION      8'h02

	//Memory Location for I2C_0 BS Gain Information
    `define I2C_0_WRITE_BS_CMD_MEMORY_LOCATION    8'h03
    `define I2C_0_WRITE_BS_DATA_MEMORY_LOCATION   8'h04
    `define I2C_0_READ_BS_DATA1_MEMORY_LOCATION   8'h05
    `define I2C_0_READ_BS_DATA2_MEMORY_LOCATION   8'h06
	
	//Memory Location for I2C_0 RG Gain Information
    `define I2C_0_WRITE_RG_CMD_MEMORY_LOCATION    8'h07
    `define I2C_0_WRITE_RG_DATA_MEMORY_LOCATION   8'h08
    `define I2C_0_READ_RG_DATA1_MEMORY_LOCATION   8'h09
    `define I2C_0_READ_RG_DATA2_MEMORY_LOCATION   8'h0a
	
	//Memory Location for PGA Channel Gain Information
    `define PGA_CH1_MEMORY                        8'h10
    `define PGA_CH2_MEMORY                        8'h12
    `define PGA_CH3_MEMORY                        8'h14
    `define PGA_CH4_MEMORY                        8'h16
 
    //Memory Location for PGA Data
    `define PGA_READ_MEMORY_LOCATION              8'h1a


    //////////////////////////////////////////////////////
    //  DSO CONTROL REGISTERS
    //////////////////////////////////////////////////////
	//ADDRESS                   FUNCTION              BITS
    //0x0                       ADC Control           0 - Start ADC Conversions
	//                                                1 - 
	//                                                2 - 
	//                                                3 - Stop ADC Conversion
	//                                                4 - adc_scan_channel_1
	//                                                5 - adc_scan_channel_2
	//                                                6 - adc_scan_channel_3
	//                                                7 - adc_scan_channel_4
    //0x01                      SPI Control           0 - Write to PGA Channel 1 (Contents of Memory location 0x10)
	//                                                1 - Write to PGA Channel 2 (Contents of Memory location 0x12)
	//                                                2 - Write to PGA Channel 3 (Contents of Memory location 0x14)
	//                                                3 - Write to PGA Channel 4 (Contents of Memory location 0x16)
	//                                                4 - Read from PGA Channel 1 (Add Contents to Memory location 0x1a)
	//                                                5 - Read from PGA Channel 2 (Add Contents to Memory location 0x1a)
	//                                                6 - Read from PGA Channel 3 (Add Contents to Memory location 0x1a)
	//                                                7 - Read from PGA Channel 4 (Add Contents to Memory location 0x1a)
    //0x02                      I2C - 0 Control       0 - 
	//                                                1 - 
	//                                                2 - 
	//                                                3 - 
	//                                                4 - 
	//                                                5 - 
	//                                                6 - 
	//                                                7 - 
    //0x03                      I2C - 1 Control       0 - 
	//                                                1 - 
	//                                                2 - 
	//                                                3 - 
	//                                                4 - 
	//                                                5 - 
	//                                                6 - 
	//                                                7 - 
    //0x04       ADC CONVST Delay Value Control       0 - Update the adc_convst_delay_value register
	//                                                1 - 
	//                                                2 - 
	//                                                3 - 
	//                                                4 - 
	//                                                5 - 
	//                                                6 - 
	//                                                7 - 
    //0x05       Reset Control                        0 - Issue a software reset (Self Resetting Bit)
	//                                                1 - 
	//                                                2 - 
	//                                                3 - 
	//                                                4 - 
	//                                                5 - 
	//                                                6 - 
	//                                                7 - 

    //////////////////////////////////////////////////////
    //  DSO CONTROL REGISTER Bits
    //////////////////////////////////////////////////////

	//ADC CONVST Delay Register Commands
    `define ADC_CONVST_DELAY_COMMAND              8'h10
 

    //Memory Read Cycle, Wait States for MEMORY_RD_DATA
    `define MEMORY_RD_LATCH_WAIT_STATE	          8'h05
    `define MEMORY_RD_COMPLETE_WAIT_STATE	      8'h0a

    //////////////////////////////////////////////////////
    //  DSO Commands
    //////////////////////////////////////////////////////

    //PGA Commands
    `define PGA_WRITE_COMMAND                     8'h2a
    `define PGA_READ_COMMAND                      8'h3a
	
    //I2C Bus 0 Commands
    `define I2C_WRITE_COMMAND                     1'h0
    `define I2C_READ_COMMAND                      1'h1
	
	//MCP4451 Commands
    `define MCP4451_FIXED_ADDRESS                 5'h0b

   //Memory Read Wait States
    `define MEMORY_RD_WAIT_STATES                 8'h03 
	
	`endif //  `ifndef _TOP_DEFINE

